#!/usr/bin/env python
# -*- coding: utf-8 -*-
from __future__ import unicode_literals, print_function

__author__ = 'harryberlin'

import os
import sys
import platform
import xbmc
import xbmcgui
import xbmcaddon
from xbmcvfs import translatePath as xbmc_translate_path

PY2 = sys.version_info[0] == 2

ADDON = xbmcaddon.Addon()
ADDON_NAME = ADDON.getAddonInfo('name')
ADDON_ID = ADDON.getAddonInfo('id')
ADDON_VERSION = ADDON.getAddonInfo('version')
ADDON_PATH = ADDON.getAddonInfo('path')
ADDON_USER_PATH = os.path.join(xbmc_translate_path('special://userdata'), 'addon_data', ADDON_ID)
ADDON_ICON = os.path.join(ADDON_PATH, 'icon.png')
ADDON_M3UFILE = os.path.join('home', 'osmc', 'Music', 'testscript.m3u')

if 'windows' in platform.system().lower():
    ADDON_M3UFILE = os.path.join(ADDON_USER_PATH, 'testscript.m3u')


XBMC_LOG_LEVEL = xbmc.LOGINFO


def log(msg):
    msg = msg.encode('utf-8', 'surrogateescape').decode('ISO-8859-1')
    xbmc.log(u'%s: SRV: %s' % (ADDON_ID, msg), XBMC_LOG_LEVEL)


def note(heading, message=None, time=-1, icon=None):
    if time == -1:
        xbmcgui.Dialog().notification(heading='%s' % heading, message='%s' % message if message else ' ', icon='%s' % (icon if icon else ADDON_ICON))
    else:
        xbmcgui.Dialog().notification(heading='%s' % heading, message='%s' % message if message else ' ', icon='%s' % (icon if icon else ADDON_ICON), time=time)
    log('NOTIFICATION: "%s%s"' % (heading, ' - %s' % message if message else ''))


def debug(string):
    log('DEBUG: %s' % string)


def main():
    media = 'audio'
    time = xbmc.Player().getTime()
    plist = xbmc.PlayList(0)
    plsize = plist.size()
    playing = xbmc.Player().getPlayingFile()
    window = xbmcgui.getCurrentWindowId()
    plpos = plist.getposition()

    if time > 0:
        if not os.path.exists(ADDON_USER_PATH):
            os.mkdir(ADDON_USER_PATH)

        with open(ADDON_M3UFILE, 'w', encoding='utf-8', errors='surrogateescape') as m3ufile:
        #with open(ADDON_M3UFILE, 'w') as m3ufile:
            m3ufile.write('#EXTCPlayListM3U::M3U\n')
            debug('writing m3u tracks started')
            if plsize != '-':
                for i in range(0, plsize):
                    temp = os.path.split(plist[i].getPath())[1]

                    debug('#EXTINF:0,%s\n' % temp)
                    m3ufile.write(f'#EXTINF:0,{temp}\n')

                    temp = plist[i].getPath()
                    debug('%s\n' % temp)
                    m3ufile.write(f'{temp}\n')

            debug('writing m3u tracks finished')

            debug('writing extra tags started')

            debug(f'#MEDIA::{media}\n')
            m3ufile.write(f'#MEDIA::{media}\n')

            debug(f'#TIME::{time}\n')
            m3ufile.write(f'#TIME::{time}\n')

            debug(f'#PLPOS::{plpos}\n')
            m3ufile.write(f'#PLPOS::{plpos}\n')

            debug(f'#PLSIZE::{plsize}\n')
            m3ufile.write(f'#PLSIZE::{plsize}\n')

            debug(f'#PLAYING::{playing}\n')
            m3ufile.write(f'#PLAYING::{playing}\n')

            debug(f'#WINDOW::{window}\n')
            m3ufile.write(f'#WINDOW::{window}\n')

            debug('#STORE::DONE\n')
            m3ufile.write(f'#STORE::DONE\n')

            debug('writing extra tags finished')

            note('script fishied fine')

def test():
    plist = xbmc.PlayList(0)
    plsize = plist.size()
    for i in range(0, plsize):
        xbmc.log(plist[i].getPath().encode('utf-8', 'surrogateescape').decode('cp1252'), xbmc.LOGINFO)

if __name__ == '__main__':
    main()
    #test()
